// ------------------------------------------------------------------------
// ecaresources.cpp: User settings (~/.ecasoundrc)
// Copyright (C) 1999 Kai Vehmanen (kaiv@wakkanet.fi)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
// ------------------------------------------------------------------------

#include <map>
#include <string>
#include <cstdlib>
#include <fstream>

#include "ecaresources.h"

ECARESOURCES::ECARESOURCES(void) { set_defaults(); }

string ECARESOURCES::resource_file(void) {
  return( string(getenv("HOME")) + "/" + ".ecasoundrc" );
}

void ECARESOURCES::load(void) {
  ifstream fin (resource_file().c_str());

  string first, second;

  while(fin >> first) {
    fin >> second; 
    if (!fin.eof()) {
      rcmap[first] = second;
    }
    while(fin.get() != '\n' && !fin.eof());
  }
  fin.close();
}
 
void ECARESOURCES::save(void) {
  ofstream fout (resource_file().c_str());

  map<string,string>::const_iterator p = rcmap.begin();
  while(p != rcmap.end()) {
    fout << p->first << " " << p->second << "\n";
    ++p;
  }
  fout.close();

}

void ECARESOURCES::set_defaults(void) {
  rcmap["home-dir"] = string(getenv("HOME"));
  rcmap["midi-device"] = "/dev/midi";
  rcmap["default-output"] = "/dev/dsp";
  rcmap["file-genosc-envelopes"] = rcmap["home-dir"] + "/" + "ecasound-genosc.dat";
}

string ECARESOURCES::resource(const string& tag) {
  return(rcmap[tag]); 
}

void ECARESOURCES::resource(const string& tag, const string& value) {
  rcmap[tag] = value;
}
